Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/httpx/__init__.py | (no class) | 15 | 0 | 0 | 100%
src/httpx/_client.py | Client | 25 | 0 | 0 | 100%
src/httpx/_client.py | RedirectMiddleware | 11 | 4 | 0 | 64%
src/httpx/_client.py | (no class) | 37 | 0 | 0 | 100%
src/httpx/_content.py | Content | 1 | 1 | 0 | 0%
src/httpx/_content.py | Form | 43 | 0 | 0 | 100%
src/httpx/_content.py | File | 14 | 2 | 0 | 86%
src/httpx/_content.py | Files | 29 | 1 | 0 | 97%
src/httpx/_content.py | JSON | 5 | 0 | 0 | 100%
src/httpx/_content.py | Text | 4 | 0 | 0 | 100%
src/httpx/_content.py | HTML | 4 | 0 | 0 | 100%
src/httpx/_content.py | MultiPart | 20 | 0 | 0 | 100%
src/httpx/_content.py | (no class) | 74 | 0 | 0 | 100%
src/httpx/_headers.py | Headers | 46 | 5 | 0 | 89%
src/httpx/_headers.py | (no class) | 28 | 0 | 0 | 100%
src/httpx/_network.py | NetworkStream | 29 | 4 | 0 | 86%
src/httpx/_network.py | NetworkBackend | 5 | 0 | 0 | 100%
src/httpx/_network.py | (no class) | 45 | 0 | 0 | 100%
src/httpx/_pool.py | Transport | 9 | 2 | 0 | 78%
src/httpx/_pool.py | ConnectionPool | 46 | 3 | 0 | 93%
src/httpx/_pool.py | Connection | 67 | 2 | 0 | 97%
src/httpx/_pool.py | (no class) | 84 | 4 | 0 | 95%
src/httpx/_request.py | Request | 25 | 1 | 0 | 96%
src/httpx/_request.py | (no class) | 10 | 0 | 0 | 100%
src/httpx/_response.py | Response | 22 | 1 | 0 | 95%
src/httpx/_response.py | (no class) | 12 | 0 | 0 | 100%
src/httpx/_server.py | ConnectionClosed | 0 | 0 | 0 | 100%
src/httpx/_server.py | HTTPConnection | 64 | 12 | 0 | 81%
src/httpx/_server.py | HTTPServer | 3 | 2 | 0 | 33%
src/httpx/_server.py | TCPServer | 38 | 3 | 0 | 92%
src/httpx/_server.py | (no class) | 48 | 0 | 0 | 100%
src/httpx/_streams.py | Stream | 2 | 0 | 0 | 100%
src/httpx/_streams.py | ByteStream | 6 | 0 | 0 | 100%
src/httpx/_streams.py | IterByteStream | 19 | 0 | 0 | 100%
src/httpx/_streams.py | FileStream | 8 | 3 | 0 | 62%
src/httpx/_streams.py | (no class) | 41 | 0 | 0 | 100%
src/httpx/_urlencode.py | (no class) | 44 | 0 | 0 | 100%
src/httpx/_urlparse.py | InvalidURL | 0 | 0 | 0 | 100%
src/httpx/_urlparse.py | ParseResult | 9 | 3 | 0 | 67%
src/httpx/_urlparse.py | (no class) | 182 | 50 | 0 | 73%
src/httpx/_urls.py | URL | 53 | 27 | 0 | 49%
src/httpx/_urls.py | QueryParams | 50 | 0 | 0 | 100%
src/httpx/_urls.py | (no class) | 67 | 0 | 0 | 100%
Total |  | 1344 | 130 | 0 | 90%

No items found using the specified filter.